#ifndef TARTANALOOPMANAGER_HH
#define TARTANALOOPMANAGER_HH

#include <deque>

#include "TObject.h"

class TThread;
class TDirectory;
class TString;
class TCutG;

class TArtAnaLoop;

//alias
void book(TArtAnaLoop* analoop, const char* anafilename = 0);
void push(const char* filename = 0, int eventnumber = -1);
void pop(int i);
void start();
void stop();
void next();
void end();
void clear();
void status();

TCutG* hcut(int id = 0, const char* filename = 0, const char* cutname = 0);

class TArtAnaLoopManager
{
  friend class TArtAnaLoop;
  friend class TArtAnaLoopStatic;

public:
  static TThread* Book(TArtAnaLoop* analoop, const char* anafilename = 0);
  static void PushRidf(const char* filename = 0, int eventnumber = -1);
  static void PopRidf(int i);
  static void Start();
  static void Stop();
  static void Next();
  static void End();
  static void ClearAll();
  static void Status();

  static TCutG* HCut(int id = 0, const char* filename = 0, const char* cutname = 0);

private:
  static void ClearHist();

  enum EAnalysisState{INIT, RUNNING, SUSPENDED, NEXT, END, ERROR};
  static EAnalysisState kAnalysisState;

  static TThread* fThread;
  static bool fLock;

  static bool fAnaFileLast;//chech last call was using anafile

  static const int fSystemWait = 100;

  static std::deque<const char*> fNextRidfFileName;
  static std::deque<int> fNextRidfEventNumber;

  static std::deque<const char*> fPrevRidfFileName;

private:
  TArtAnaLoopManager(){;}
  virtual ~TArtAnaLoopManager();

  ClassDef(TArtAnaLoopManager,1);
};

//analoopにstaticにアクセスするための窓口
//窓口だけの役割とするため、基本的にanaloop自体を管理したりはしない。
//つまりfAnaLoopの管理は他で管理してもらう。
class TArtAnaLoopStatic
{
public:
  static void* AnaLoopStatic(void *);

  static void SetAnaLoop(TArtAnaLoop* analoop);
  static void SetFileName(const char* filename);
  static void SetEventNumber(int eventnumber);
  static void SetDirectory(TDirectory* directory);

  static TArtAnaLoop* GetAnaLoop();
  static const char* GetFileName();
  static int GetEventNumber();
  static TDirectory* GetDirectory();

  static void Clear();

private:
  static TArtAnaLoop* fAnaLoop;
  static TString fFileName;
  static int fEventNumber;

  static TDirectory* fDirectory;

private:
  TArtAnaLoopStatic(){;}
  virtual ~TArtAnaLoopStatic();

  ClassDef(TArtAnaLoopStatic,1);
};

#endif
