#include "TArtCalibPID.h" 
#include "TArtCalibPPAC.h"
#include "TArtCalibPlastic.h"
#include "TArtPlastic.h"
#include "TArtCalibIC.h"
#include "TArtCalibFocalPlane.h" 
#include "TArtBigRIPSParameters.h"
#include "TArtFocalPlanePara.h" 
#include "TArtRawEventObject.h"
#include "TArtCore.h" 
#include "TArtStoreManager.h"

#include <TROOT.h>

#include "segidlist.h"

//__________________________________________________________
TArtCalibPID::TArtCalibPID()
  :fDataLoaded(false), fReconstructed(false)
{
  TArtCore::Info(__FILE__,"Creating the BigRIPS/ZeroDegree detector objects...");
  sman = TArtStoreManager::Instance();
  setup = (TArtBigRIPSParameters*)sman->FindParameters("BigRIPSParameters");
  if(!setup){
    TArtCore::Info(__FILE__,"Can not find parameter handler: BigRIPSParameters");
    throw;
  }

  fCalibPPAC    = new TArtCalibPPAC();
  fCalibPlastic = new TArtCalibPlastic();
  fCalibIC      = new TArtCalibIC();
  fCalibFocalPlane = new TArtCalibFocalPlane();
}

//__________________________________________________________
TArtCalibPID::~TArtCalibPID()  {
  ClearData();
}

//__________________________________________________________
void TArtCalibPID::LoadData()   {

  TArtRawEventObject *fEvent = (TArtRawEventObject *)sman->FindDataContainer("RawEvent");
  for(int i=0;i<fEvent->GetNumSeg();i++){
    TArtRawSegmentObject *seg = fEvent->GetSegment(i);
    int device = seg->GetDevice();
    if(BIGRIPS == device || ZeroDegree == device)
      LoadData(seg);
  }
  return;

}

//__________________________________________________________
void TArtCalibPID::LoadData(TArtRawSegmentObject *seg)   {

  ClearData();
  int detector = seg->GetDetector();
  if(PPACT == detector || PPACQ == detector)
    fCalibPPAC->LoadData(seg);
  if(PLAT == detector || PLAQ == detector)
    fCalibPlastic->LoadData(seg);
  if(ICE == detector) 
    fCalibIC->LoadData(seg);
  fDataLoaded = true;
  return;

}

//__________________________________________________________
void TArtCalibPID::ClearData()   {

  fCalibPPAC->ClearData();
  fCalibPlastic->ClearData();
  fCalibIC->ClearData();
  fCalibFocalPlane->ClearData();
  fDataLoaded = false;
  fReconstructed = false;
  return;

}

//__________________________________________________________
void TArtCalibPID::ReconstructData()   {

  if(!fDataLoaded) LoadData();
  fCalibPPAC->ReconstructData();
  fCalibPlastic->ReconstructData();
  fCalibIC->ReconstructData();
  fCalibFocalPlane->ReconstructData();

  TClonesArray *pla_array = GetPlasticArray();
  // set global z in each plastic
  for(int i=0;i<pla_array->GetEntries();i++){
    TArtPlastic *pla = (TArtPlastic *)pla_array->At(i);
    int fpl = pla->GetFpl();
    Double_t zpos = setup->GetFocalPlanePara(fpl)->GetZpos();
    pla->SetZposition(zpos + pla->GetZoffset());
  }

  fReconstructed = true;
  return;
}

//__________________________________________________________
TClonesArray * TArtCalibPID::GetPPACArray(){
  return fCalibPPAC->GetPPACArray();
}
//__________________________________________________________
TClonesArray * TArtCalibPID::GetPlasticArray(){
  return fCalibPlastic->GetPlasticArray();
}
//__________________________________________________________
TClonesArray * TArtCalibPID::GetICArray(){
  return fCalibIC->GetICArray();
}
//__________________________________________________________
TClonesArray * TArtCalibPID::GetFocalPlaneArray(){
  return fCalibFocalPlane->GetFocalPlaneArray();
}
