#ifndef _TARTSISTOPPERPARA_H_
#define _TARTSISTOPPERPARA_H_

#include <Riostream.h>

#include "TArtMap.h"
#include "segidlist.h"

class TArtSiStopperPara : public TNamed {

 public:
  TArtSiStopperPara(){}
  TArtSiStopperPara(Int_t i, TString n, Int_t f, Int_t l, Double_t tc, Double_t to, Double_t qc, Double_t qp, Double_t hiqc, Double_t hiqp) :
    id(i), detname(n), fpl(f), layer(l), tcal(tc), toff(to), qcal(qc), qped(qp), hiqcal(hiqc), hiqped(hiqp){ }
  ~TArtSiStopperPara() { }

  void SetParameters(Int_t i, TString n, Int_t f, Int_t l, Double_t tc, Double_t to, Double_t qc, Double_t qp, Double_t hiqc, Double_t hiqp) { id=i; detname=n; fpl=f; layer=l; tcal=tc; toff=to; qcal=qc; qped=qp; hiqcal=hiqc; hiqped=hiqp; }

  void SetMap(Int_t tgeo, Int_t tch, Int_t qgeo, Int_t qch, Int_t hiqgeo, Int_t hiqch) {
    map_adc.SetMap(fpl,BETAA,qgeo,qch); 
    cout << "ADC is mapped to " << map_adc.GetMapInfo() << " " << map_adc.GetName() << endl;
    map_hiadc.SetMap(fpl,HIA,hiqgeo,hiqch); 
    cout << "HI-ADC is mapped to " << map_hiadc.GetMapInfo() << " " << map_hiadc.GetName() << endl;
    map_tdc.SetMap(fpl,BETAT,tgeo,tch); 
    cout << "TDC is mapped to " << map_tdc.GetMapInfo() << " " << map_tdc.GetName() << endl;
  }

  Int_t GetID() const { return id; }
  TString * GetDetectorName() { return &detname; }
  Int_t GetFpl() const { return fpl; }
  Int_t GetLayer() const { return layer; }
  Double_t GetTCal() const { return tcal; } 
  Double_t GetTOffset() const { return toff; } 
  Double_t GetQCal() const { return qcal; } 
  Double_t GetQPed() const { return qped; } 
  Double_t GetHIQCal() const { return hiqcal; } 
  Double_t GetHIQPed() const { return hiqped; } 

  TArtRIDFMap * GetTDCMap() { return &map_tdc;  }
  TArtRIDFMap * GetADCMap() { return &map_adc;  }
  TArtRIDFMap * GetHIADCMap() { return &map_hiadc;  }

  friend ostream & operator << (ostream& out, const TArtSiStopperPara& p) {
    out << "ID: " << p.id << endl;
    out << "DetectorName: " << p.detname << endl;
    out << "Focal Plane: " << p.fpl << endl;
    out << "NaI Layer: " << p.layer << endl;
    out << "Time Calib: " << p.tcal << endl;
    out << "Time Offset: " << p.toff << endl;
    out << "QDC Calib: " << p.qcal << endl;
    out << "QDC pedestal: " << p.qped << endl;
    out << "HI-QDC Calib: " << p.hiqcal << endl;
    out << "HI-QDC pedestal: " << p.hiqped << endl;
    out << "Map of ADC: "  << p.map_adc << endl;
    out << "Map of HI-ADC: "  << p.map_hiadc << endl;
    out << "Map of TDC: "  << p.map_tdc << endl;
    out << endl;
    return out;
  }

 private:
  Int_t     id;
  TString   detname;
  Int_t     fpl;
  Int_t     layer;
  Double_t  tcal;
  Double_t  toff;
  Double_t  qcal;
  Double_t  qped;
  Double_t  hiqcal;
  Double_t  hiqped;
  TArtRIDFMap map_tdc;
  TArtRIDFMap map_adc;
  TArtRIDFMap map_hiadc;

  ClassDef(TArtSiStopperPara,1);

};

#endif
