#ifndef _TARTNEBULAPLAPARA_H_
#define _TARTNEBULAPLAPARA_H_

#include "TArtMap.h"

class TArtSAMURAIParameters;

class TArtNEBULAPlaPara : public TObject
{
  friend class TArtSAMURAIParameters;

public:
  TArtNEBULAPlaPara(Int_t id = -1, const TString& detname = "",
		    Int_t fpl = -1, Int_t layer = -1, Int_t sublayer = -1, const Double_t* detpos = 0, 
		    Double_t tucal = 1, Double_t tuoff = 0, Double_t tuslw = 0,
		    Double_t qucal = 1, Double_t quped = 0,
		    Double_t tdcal = 1, Double_t tdoff = 0, Double_t tdslw = 0,
		    Double_t qdcal = 1, Double_t qdped = 0,
		    Double_t dtcal = 1, Double_t dtoff = 0, Double_t taveoff = 0,
		    Int_t ignore = 0)
    : TObject(),
      fID(id), fDetName(detname),
      fFPl(fpl), fLayer(layer), fSubLayer(sublayer),
      fTUCal(tucal), fTUOff(tuoff), fTUSlw(tuslw),
      fQUCal(qucal), fQUPed(quped),
      fTDCal(tdcal), fTDOff(tdoff), fTDSlw(tdslw),
      fQDCal(qdcal), fQDPed(qdped),
      fDTCal(dtcal), fDTOff(dtoff), fTAveOff(taveoff),
      fIgnore(ignore)
  {
    if(detpos) for(int i=0; i<3; ++i) fDetPos[i] = detpos[i];
    else for(int i=0; i<3; ++i) fDetPos[i] = 0;
  }
  ~TArtNEBULAPlaPara(){;}

  void SetID(Int_t val){fID = val;}
  void SetDetectorName(const TString& val){fDetName = val;}
  void SetFPl(Int_t val){fFPl = val;}
  void SetLayer(Int_t val){fLayer = val;}
  void SetSubLayer(Int_t val){fSubLayer = val;}
  void SetDetPos(const Double_t* val){for(int i=0; i<3; ++i) fDetPos[i] = val[i];}
  void SetDetPos(Double_t val, Int_t i){fDetPos[i] = val;} 
  void SetTUCal(Double_t val){fTUCal = val;} 
  void SetTUOff(Double_t val){fTUOff = val;} 
  void SetTUSlw(Double_t val){fTUSlw = val;} 
  void SetQUCal(Double_t val){fQUCal = val;} 
  void SetQUPed(Double_t val){fQUPed = val;} 
  void SetTDCal(Double_t val){fTDCal = val;} 
  void SetTDOff(Double_t val){fTDOff = val;} 
  void SetTDSlw(Double_t val){fTDSlw = val;} 
  void SetQDCal(Double_t val){fQDCal = val;} 
  void SetQDPed(Double_t val){fQDPed = val;} 
  void SetDTCal(Double_t val){fDTCal = val;} 
  void SetDTOff(Double_t val){fDTOff = val;} 
  void SetTAveOff(Double_t val){fTAveOff = val;} 
  void SetIgnore(Int_t val){fIgnore = val;}

  Int_t GetID() const {return fID;}
  const TString& GetDetectorName() const {return fDetName;}
  Int_t GetFPl() const {return fFPl;}
  Int_t GetLayer() const {return fLayer;}
  Int_t GetSubLayer() const {return fSubLayer;}
  const Double_t* GetDetPos() const {return fDetPos;} 
  Double_t GetDetPos(int i) const {return fDetPos[i];} 
  Double_t GetTUCal() const {return fTUCal;} 
  Double_t GetTUOff() const {return fTUOff;} 
  Double_t GetTUSlw() const {return fTUSlw;} 
  Double_t GetQUCal() const {return fQUCal;} 
  Double_t GetQUPed() const {return fQUPed;} 
  Double_t GetTDCal() const {return fTDCal;} 
  Double_t GetTDOff() const {return fTDOff;} 
  Double_t GetTDSlw() const {return fTDSlw;} 
  Double_t GetQDCal() const {return fQDCal;} 
  Double_t GetQDPed() const {return fQDPed;} 
  Double_t GetDTCal() const {return fDTCal;} 
  Double_t GetDTOff() const {return fDTOff;} 
  Double_t GetTAveOff() const {return fTAveOff;} 
  Int_t GetIgnore() const {return fIgnore;}

  friend ostream& operator<<(ostream& out, const TArtNEBULAPlaPara& p){
    out << "ID: "          << p.fID      << endl;
    out << "Det. Name: "   << p.fDetName << endl;
    out << "Focal Plane: " << p.fFPl     << endl;
    out << "Layer: "       << p.fLayer   << endl;
    out << "SubLayer: "    << p.fSubLayer<< endl;
    out << "Det. Pos.: "   << p.fDetPos[0]  << " " << p.fDetPos[1]<< " " << p.fDetPos[2]<< endl;
    out << "TU Calib: "    << p.fTUCal   << endl;
    out << "TU Offset: "   << p.fTUOff   << endl;
    out << "TU Slew: "     << p.fTUSlw   << endl;
    out << "QU Calib: "    << p.fQUCal   << endl;
    out << "QU Pedestal: " << p.fQUPed   << endl;
    out << "TD Calib: "    << p.fTDCal   << endl;
    out << "TD Offset: "   << p.fTDOff   << endl;
    out << "TD Slew: "     << p.fTDSlw   << endl;
    out << "QD Calib: "    << p.fQDCal   << endl;
    out << "QD Pedestal: " << p.fQDPed   << endl;
    out << "dT Calib: "    << p.fDTCal   << endl;
    out << "dT Offset: "   << p.fDTOff   << endl;
    out << "TAve Offset: " << p.fTAveOff << endl;
    out << "Ignore: "      << p.fIgnore  << endl;
    out << "Map of TU: "   << p.fMapTU  << endl;
    out << "Map of QU: "   << p.fMapQU  << endl;
    out << "Map of TD: "   << p.fMapTD  << endl;
    out << "Map of QD: "   << p.fMapQD  << endl;
    out << endl;
    return out;
  }

  const TArtRIDFMap& GetMapTU() const {return fMapTU;}
  const TArtRIDFMap& GetMapQU() const {return fMapQU;}
  const TArtRIDFMap& GetMapTD() const {return fMapTD;}
  const TArtRIDFMap& GetMapQD() const {return fMapQD;}

private:
  Int_t     fID;
  //  TString   fUDLR;
  TString   fDetName;
  Int_t     fFPl;
  Int_t     fLayer;
  Int_t     fSubLayer;
  Double_t  fDetPos[3];
  Double_t  fTUCal;
  Double_t  fTUOff;
  Double_t  fTUSlw;
  Double_t  fQUCal;
  Double_t  fQUPed;
  Double_t  fTDCal;
  Double_t  fTDOff;
  Double_t  fTDSlw;
  Double_t  fQDCal;
  Double_t  fQDPed;
  Double_t  fDTCal;
  Double_t  fDTOff;
  Double_t  fTAveOff;
  Int_t     fIgnore;

  void SetMapTU(Int_t tu_geo, Int_t tu_ch){fMapTU.SetMap(fFPl,41,tu_geo,tu_ch);}
  void SetMapQU(Int_t qu_geo, Int_t qu_ch){fMapQU.SetMap(fFPl,42,qu_geo,qu_ch);}    
  void SetMapTD(Int_t td_geo, Int_t td_ch){fMapTD.SetMap(fFPl,41,td_geo,td_ch);}
  void SetMapQD(Int_t qd_geo, Int_t qd_ch){fMapQD.SetMap(fFPl,42,qd_geo,qd_ch);}    

  //    fMapTDC.SetMap(fpl,NEBULAT,tgeo,tch); 
  //    cout << "TDC is mapped to " << fMapTDC.GetMapInfo() << " " << fMapTDC.GetName() << endl;

  TArtRIDFMap fMapTU, fMapQU, fMapTD, fMapQD;

  ClassDef(TArtNEBULAPlaPara,1);
};

#endif
